/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {navigate} from 'frontend-js-web';

const ACTIONS = {
	disconnect({url: disconnectSiteActionURL}) {
		if (
			confirm(
				Liferay.Language.get(
					'removing-this-site-connection-will-not-allow-the-site-to-consume-data-from-this-asset-library-directly'
				)
			)
		) {
			submitForm(document.hrefFm, disconnectSiteActionURL);
		}
	},
	shareWebContentStructures({
		shared,
		url: updateDDMStructuresAvailableActionURL,
	}) {
		const message = shared
			? Liferay.Language.get(
					'after-disabling-structure-sharing,-any-site-content-that-uses-the-structures-will-be-invalid.-do-you-want-to-disable-structure-sharing'
			  )
			: Liferay.Language.get(
					'you-will-not-be-able-to-disconnect-this-site-when-structure-sharing-is-enabled.-in-order-to-disconnect-this-site-from-this-asset-library,-you-must-disable-structure-sharing-first'
			  );

		if (confirm(message)) {
			navigate(updateDDMStructuresAvailableActionURL);
		}
	},
};

export default function propsTransformer({items, ...otherProps}) {
	return {
		...otherProps,
		items: items.map((item) => {
			return {
				...item,
				onClick(event) {
					const action = item.data?.action;

					if (action) {
						event.preventDefault();

						ACTIONS[action](item.data);
					}
				},
			};
		}),
	};
}
